==> minitube-1.0.tar.gz: minitube/locale/fi_FI.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi_FI">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Elämää on muuallakin kuin selaimessa!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versio numero: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 on ilmainen ohjelma,mutta sen kehittäminen vie kallista aika.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Olisi mukaavaa jos tukisit %2 kehitystä tekemällä &lt;a href=&apos;%1&apos;&gt;lahjoituksen&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Kerro virheistä/ongelmista ja jaa ideoitasi osoitteeseen %1</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Kuvakkeen suunnitteli %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Kompaktin tilan teki %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>HTTP välityspalvelin tuen teki %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Käännöksen teki %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Julkaistu &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt; lisenssin alla</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Mitä olet aina halunnut tietää %1sta muttet ole koskaan kehdannut kysyä</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Tyhjennä</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Etsitään...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Näytä %1 lisää</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Ei videoita</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Ei enempää videoita</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Pysäytä</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Pysäytä taista ja palaa hakuruuttun</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Hyppää yli</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Siirry seuraavaan videoon</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Stoppaa</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pysäytä toistaminen</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Kokoruutu</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Vaihda kokoruutu tilaan</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>&amp;Kompakti tila</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Piilota toistolista sekä työkalupalkki</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation>Avaa &amp;Youtube sivusto</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Pysäytä toisto ja mene YouTube sivulle</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation>Kopio YouTube &amp;linkki</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopio nykyisen videon YouTube linkki</translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation>Kopio videovirran osoite (&amp;URL)</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopio nykyisen videvirran osoite (URL)</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Poista valittu video listalta</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Siirrä &amp;Ylös päin</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Siirrä valittu video ylemmäksi listalla</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Sirrä &amp;Alas päin</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Siirrä valittu video alemmaksi listalla</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>&amp;Poista viimeisimmät haut</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Tyhjennä haku historia. Tätä toimintoa ei voi kumota.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Poistu</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Heippa</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Nettisivu</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 netissä</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Tee &amp;lahjoitus</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Tue %1n jatkuvaa kehitystä</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Tietoja</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Tiotoja %1sta</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Mykistä ääni</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Ohjelma</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Soittolista</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Apua</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Paina %1ta nostaaksesi tai %2ta laskeaksesi äänen voimakkuutta</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Avataan %1ta/tä</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Kauhia Virhe: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Virhe: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Toista</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Jatka toistoa</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Poistu &amp;kokoruudun tilasta</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Aikaa jäljellä: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Äänen tasa %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Ääni on mykistetty</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Ääni ei ole mykistetty</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Suurin videon laatu on rajoiteetu %1aan/ään</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Yksityisyytesi on nyt turvattu</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Olennaisin</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Uusin</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Katsotuin</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Voit nyt liittää YouTube linkin johonkin toiseen ohjelmaan</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Voit nyt liittää videovirran osoitteen(URL) johonkin toiseen ohjelmaan</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Osoite on käytössä vain rajoitetun ajan.</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Nyt pyörii &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Verkko virhe: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>Katsottu %1 kertaa</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;%2en&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Anna hakusana alkaaksesi katsella videoita.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Katso</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Viimeisimmät hakusanat</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Uusi versio %1sta on saatavilla. &lt;a href=&apos;%2&apos;&gt;Päivitäthän versioon %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Tee olosi kotoisaksi</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Verkko virhe: &quot;%1&quot; &quot;%2&quot;lle</translation>
    </message>
</context>
</TS>

==> minitube-1.1.tar.gz: minitube/locale/fi_FI.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi_FI">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Selaimen ulkopuolellakin on elämää!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versionumero: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 on ilmainen ohjelma,mutta sen kehittäminen vie kallista aika.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Voit tukea  %2n kehityksen jatkumista tekemällä &lt;a href=&apos;%1&apos;&gt;lahjoituksen&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Ilmoita bugit ja kerro ideasi osoitteeseen %1</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Kuvakkeen suunnitteli %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Kompaktin tilan teki %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>HTTP-välityspalvelintuen teki %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Käännöksen teki %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Julkaistu &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt; -lisenssillä</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Mitä olet aina halunnut tietää %1sta, muttet ole koskaan kehdannut kysyä</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Tyhjennä</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Etsitään...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Näytä %1 lisää</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Ei videoita</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Ei enempää videoita</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Pysäytä</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Pysäytä toisto ja palaa hakuruutuun</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Hyppää yli</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Siirry seuraavaan videoon</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Keskeytä</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Keskeytä toisto</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Kokoruutu</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Siirry kokoruututilaan</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>&amp;Kompakti tila</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Piilota toistolista sekä työkalupalkki</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation>Avaa &amp;Youtube -sivu</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Keskeytä toisto ja mene videon YouTube -sivulle</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation>Kopio YouTube -&amp;linkki</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopio nykyisen videon YouTube -linkki leikepöydälle</translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation>Kopioi videovirran osoite (&amp;URL)</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopioi nykyisen videvirran osoite (URL) leikepöydälle</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Poista valitut videot toistolistalta</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Siirrä &amp;Ylös</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Siirrä valitut videot ylemmäksi toistolistalla</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Sirrä &amp;Alas</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Siirrä valitut videot alemmaksi toistolistalla</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>&amp;Poista viimeisimmät hakusanat</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Tyhjennä hakuhistoria. Tätä toimintoa ei voi kumota.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Lopeta</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Näkemiin</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Nettisivusto</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 netissä</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Tee &amp;lahjoitus</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Tue %1n jatkokehitystä</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Tietoja</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Tietoja %1sta</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Mykistä ääni</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Sovellus</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Toistolista</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Apua</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Paina näppäinyhdistelmää %1 nostaaksesi tai %2 laskeaksesi äänenvoimakkuutta</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Avataan kohdetta %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Kohtalokas virhe: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Virhe: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Toista</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Jatka toistoa</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Poistu &amp;kokoruudun tilasta</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Aikaa jäljellä: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Äänentaso: %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Ääni on mykistetty</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Ääni ei ole mykistetty</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Korkein videonlaatu on rajoitettu tarkkuteen %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Yksityisyytesi on nyt turvattu</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Osuvin</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Viimeisin</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Katsotuin</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Voit nyt liittää YouTube-linkin johonkin toiseen sovellukseen</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Voit nyt liittää videovirran osoitteen (URL) johonkin toiseen sovellukseen</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Osoite on käytössä vain rajoitetun ajan.</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Nyt pyörii &quot;%1&quot;</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Verkkovirhe: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>Katsottu %1 kertaa</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Tervetuloa &lt;a href=&apos;%1&apos;&gt;%2en&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Anna hakusana aloittaaksesi videoiden katselu.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Katso</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Viimeisimmät hakusanat</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Uusi versio %1sta on saatavilla. &lt;a href=&apos;%2&apos;&gt;Päivitäthän versioon %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Tee olosi kotoisaksi</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Verkkovirhe: &quot;%1&quot; &quot;%2&quot;lle</translation>
    </message>
</context>
</TS>
